{ lib, pkgs, modulesPath, inputs, ... }:

with lib;
let
  defaultUser = "michael";
in
{
  imports = [
    "${modulesPath}/profiles/minimal.nix"

    inputs.nixos-wsl.nixosModules.wsl
  ];

  wsl = {
    enable = true;
    wslConf = {
      automount.root = "/mnt";
      interop.appendWindowsPath = false;
    };
    defaultUser = defaultUser;
    startMenuLaunchers = true;

    # Enable integration with Docker Desktop (needs to be installed)
    # docker.enable = true;
  };

  time.timeZone = "America/New_York";

  programs.adb.enable = true;

  # Required because for some reason WSL kernel doesn't play well with nftables
  networking.firewall.package = pkgs.iptables-legacy;

  home-manager = {
    users.michael = import ../../user/environments/wsl/home.nix pkgs;
    useGlobalPkgs = true;
  };

  environment.systemPackages = with pkgs; [
    wget
  ];

  services.vscode-server.enable = true;

  programs.zsh.enable = true;

  users.users.${defaultUser} = {
    uid = pkgs.lib.mkForce 1001;
    extraGroups = [ "wheel" "docker" "podman" ];
    shell = pkgs.zsh;
  };

  system.stateVersion = "22.05";
}
